// ***********************************************
// Random sounds script
// (courtesy of ScentedNectars challenge 01/09/04)
// Description: plays random sounds at a random interval 
//              of time between each sound. 
// 
// How to use: 
// 1. Add the names of your sound files below
// 2. Set the 'mintime' and 'maxdifference' below
//    For example: if you want sound to play between 
//    10 and 30 seconds interval set
//      this.sounds.mintime = 10;
//      this.sounds.maxdifference = 20;
// 
// ***********************************************

// ----------------------------------------------------
// Set the names of your sound files here

this.sounds = [
	"./bird1.mp3",
	"./bird2.mp3",
	"./bird3.mp3",
	"./bird4.mp3",
	"./bird5.mp3",
	"",
	"",
""];


// ----------------------------------------------------
// The minimum time spend waiting between sounds. 
// Example. Default is set to 1 second. This means that 
// the time between when a sound finishes and the next
// sound begins is a minimum of 1 second. 
// You may set any minimum time amount. 

this.sounds.mintime = 1;


// ----------------------------------------------------
// The maximum time spent waiting for a new sound to be played. 
// This number reflects the range of time between when a 
// sound finished and the next sound begins. 
// Example. If 'maxdifference' is set to 8, then the 
// random waiting time is between 'mintime' 
// and 'mintime + maxdifference'. 
// In other words, between '1' and '9' inclusive

this.sounds.maxdifference = 8;



// ----------------------------------------------------
// Volume of all the sounds. 
this.sounds.volume = 0.5;


// ----------------------------------------------------
// The positional height of all the sounds. 
this.sounds.height = 10;


// ----------------------------------------------------
// This allows you to enable controls buttons
// Set to true or false
this.enablecontrolbuttons = true;


// ----------------------------------------------------
// Random volume deviation. 
// You can set the volume to randomly deviation up
// and down a certain amount. 
// Default is set to 0.1. 
// Example. If you set the 'randomvolumedeviation=0.1'
// and volume=0.5, then the volume will range between 
// 0.4 and 0.6

this.sounds.randomvolumedeviation = 0.1;



// ================================================
// Do not change after this point
// ================================================
this.soundsobj = Object();
this.soundsobj.sounds = this.sounds;           // original string array sounds
this.soundsobj.soundarray = [];                // array of Sound objects
this.soundsobj.timesince = 0;                  // time since last sound
this.soundsobj.currentsound = undefined;       // current sound played
this.soundsobj.randtimediff = 3;               // random time until next sound
this.soundsobj.timestep = function(w, d) {

	// Check that a current sound exists
	if(this.currentsound==undefined) this.currentsound = this.soundarray[0];

	// If the current sound is not playing, we time count
	// until the next sound is required to play
	if(!this.currentsound.active) this.timesince += d;

	// Play the sound 
	if(this.timesince > (this.sounds.mintime+this.randtimediff)) {
		this.currentsound = this.soundarray[randint(this.soundarray.length)];

		// Set the sound at a random position
		this.currentsound.position = this.sounds.randposition();
		
		// Set the sound with a random volume
		var vol = this.sounds.volume + (this.sounds.randomvolumedeviation * (rnd()-0.5));
		if(vol>1.0) vol = 1.0;
		if(vol<0.0) vol = 0.0;
		this.currentsound.volume = vol;

		// Plays the sound
		this.currentsound.play();
		this.randtimediff = randint(this.sounds.maxdifference);
		this.timesince = 0;		
	}
}


// Loads the sound objects
this.soundsobj.loaded = false;
this.soundsobj.loadup = function() {
	// local variable... no reason for this.... 
	var soundarray = this.soundarray;

	for(var i=0; i<this.sounds.length; i++) {
		if(this.sounds[i].length>1) {
	
			// Create a new sound object
			var snd = Sound(this.sounds[i]);
			snd.URL = this.sounds[i];
			snd.active = false;
			snd.repeats = 1;
			snd.volume = this.sounds.volume;
			snd.near = 10;
			snd.far = 120;

			// Add it to the array using 'push'
			soundarray.push(snd);
		}
	}
	this.loaded = true;

	// Once all the sound objects are loaded, 
	// fire off the animator which runs the random
	// sounds
	addAnimator(this);
}
this.soundsobj.loadup();


// ================================================
// Random number generator
// 
// We generate our own random numbers since we 
// cannot rely on the Atmo engine to consistenly
// do so. 
// ================================================
rnd.seed = new Date().getTime();

// Random position near the actor... 
this.sounds.randposition = function() {
	var h = 10;
	if(rnd() > 0.5) {
		h = -10;
	} 
	var w = 10;
	if(rnd() > 0.5) {
		w = -10;
	}
	return [actor.position.x+h, this.height, actor.position.z+w];
}
// Random integer between zero and maxint
function randint(maxint) {
	return Math.floor(rnd() * maxint);
}

function rnd() {
 rnd.seed = (rnd.seed*9301+49297) % 233280;
 return rnd.seed/(233280.0);
}


// ================================================
// Control buttons
// ================================================

if(this.enablecontrolbuttons) {
	Button("=="+this.sounds[0]+"..etc").add();
	var vol = Slider("Volume").add();
	vol.range = [0, 1];
	vol.value = this.sounds.volume;
	vol.enabled = true;
	vol.sounds = this.sounds;
	vol.onChange = function(val) {
		this.sounds.volume = val;
	}
}



